==> maxx-0.2.6.tar.gz: maxx-0.2.6/CHANGELOG.md <==
# CHANGELOG


## v0.2.6 (2025-08-06)

### Bug Fixes

- **deps**: Update dependency griffe to ~=1.10.0
  ([#19](https://github.com/watermarkhu/maxx/pull/19),
  [`f562697`](https://github.com/watermarkhu/maxx/commit/f562697093565ce5630adc94b5fe324d11f6bb34))


## v0.2.5 (2025-07-29)

### Bug Fixes

- **deps**: Update dependency griffe to ~=1.9.0 ([#17](https://github.com/watermarkhu/maxx/pull/17),
  [`79a2dc9`](https://github.com/watermarkhu/maxx/commit/79a2dc92cd54f7548abead153e4f8242c81f71bf))


## v0.2.4 (2025-07-13)

### Bug Fixes

- Use mirror release of py-tree-sitter that supports language version 15
  ([#16](https://github.com/watermarkhu/maxx/pull/16),
  [`23f1562`](https://github.com/watermarkhu/maxx/commit/23f15629f30e0463e2bf0e16e4bde0cb760f42d6))


## v0.2.3 (2025-07-06)

### Bug Fixes

- Arguments sorting ([#14](https://github.com/watermarkhu/maxx/pull/14),
  [`d567b35`](https://github.com/watermarkhu/maxx/commit/d567b35c6d786e7153b38d9ade531f1d062d603b))

- Upload dists ([#15](https://github.com/watermarkhu/maxx/pull/15),
  [`88c223b`](https://github.com/watermarkhu/maxx/commit/88c223bb1cb4651045be46af16ebfabd467449f7))


## v0.2.2 (2025-07-02)

### Bug Fixes

- Show type information in arguments if namespace is used
  ([#12](https://github.com/watermarkhu/maxx/pull/12),
  [`d0aa656`](https://github.com/watermarkhu/maxx/commit/d0aa656d4055980454f35c00189431c638e22f2a))

- Use env to release ([#13](https://github.com/watermarkhu/maxx/pull/13),
  [`38ce50f`](https://github.com/watermarkhu/maxx/commit/38ce50f4accb87dcd2d08820d1aff03d7eb52601))


## v0.2.1 (2025-07-01)

### Bug Fixes

- Apply fixes for mkdocstrings-matlab ([#9](https://github.com/watermarkhu/maxx/pull/9),
  [`0bfe68a`](https://github.com/watermarkhu/maxx/commit/0bfe68abbc4743caa09cc02ed57f006a711a261f))

- Various fixes for mkdocstrings-matlab ([#9](https://github.com/watermarkhu/maxx/pull/9),
  [`0bfe68a`](https://github.com/watermarkhu/maxx/commit/0bfe68abbc4743caa09cc02ed57f006a711a261f))


## v0.2.0 (2025-06-02)

### Features

- Force release with semver action ([#7](https://github.com/watermarkhu/maxx/pull/7),
  [`1728e0f`](https://github.com/watermarkhu/maxx/commit/1728e0fcbd878353f11441af12d23da7d5444e88))

- Force release with semver action ([#6](https://github.com/watermarkhu/maxx/pull/6),
  [`5b23575`](https://github.com/watermarkhu/maxx/commit/5b23575d7821faf2c1064892ae12f533bbb657e3))

- Force release with semver action ([#5](https://github.com/watermarkhu/maxx/pull/5),
  [`cf7cefd`](https://github.com/watermarkhu/maxx/commit/cf7cefdbb187755143702aefcfc2fd962b73fae5))


## v0.1.0 (2025-05-24)

==> maxx-0.2.10.tar.gz: maxx-0.2.10/CHANGELOG.md <==
# CHANGELOG


## v0.2.10 (2025-08-26)

### Chores

- **deps**: Update dependency griffe to ~=1.13.0
  ([#24](https://github.com/watermarkhu/maxx/pull/24),
  [`d9c8a89`](https://github.com/watermarkhu/maxx/commit/d9c8a895a7c6d5105207f124aec10e54ee1a5d07))


## v0.2.9 (2025-08-20)

### Chores

- **deps**: Update dependency griffe to ~=1.12.1
  ([#21](https://github.com/watermarkhu/maxx/pull/21),
  [`c3ebfbd`](https://github.com/watermarkhu/maxx/commit/c3ebfbda07d4ff9602524811d4354cb29d834dd0))


## v0.2.8 (2025-08-07)

### Chores

- **deps**: Update actions/download-artifact action to v5
  ([#18](https://github.com/watermarkhu/maxx/pull/18),
  [`1d6a0da`](https://github.com/watermarkhu/maxx/commit/1d6a0da2e0f864b3306e9437e018403804e29c75))


## v0.2.7 (2025-08-07)

### Bug Fixes

- Use official tree-sitter release ([#20](https://github.com/watermarkhu/maxx/pull/20),
  [`0be3cd2`](https://github.com/watermarkhu/maxx/commit/0be3cd2bd5d57fdb37faffb2ec8d29b8ce9e8329))


## v0.2.6 (2025-08-06)

### Bug Fixes

- **deps**: Update dependency griffe to ~=1.10.0
  ([#19](https://github.com/watermarkhu/maxx/pull/19),
  [`f562697`](https://github.com/watermarkhu/maxx/commit/f562697093565ce5630adc94b5fe324d11f6bb34))


## v0.2.5 (2025-07-29)

### Bug Fixes

- **deps**: Update dependency griffe to ~=1.9.0 ([#17](https://github.com/watermarkhu/maxx/pull/17),
  [`79a2dc9`](https://github.com/watermarkhu/maxx/commit/79a2dc92cd54f7548abead153e4f8242c81f71bf))


## v0.2.4 (2025-07-13)

### Bug Fixes

- Use mirror release of py-tree-sitter that supports language version 15
  ([#16](https://github.com/watermarkhu/maxx/pull/16),
  [`23f1562`](https://github.com/watermarkhu/maxx/commit/23f15629f30e0463e2bf0e16e4bde0cb760f42d6))


## v0.2.3 (2025-07-06)

### Bug Fixes

- Arguments sorting ([#14](https://github.com/watermarkhu/maxx/pull/14),
  [`d567b35`](https://github.com/watermarkhu/maxx/commit/d567b35c6d786e7153b38d9ade531f1d062d603b))

- Upload dists ([#15](https://github.com/watermarkhu/maxx/pull/15),
  [`88c223b`](https://github.com/watermarkhu/maxx/commit/88c223bb1cb4651045be46af16ebfabd467449f7))


## v0.2.2 (2025-07-02)

### Bug Fixes

- Show type information in arguments if namespace is used
  ([#12](https://github.com/watermarkhu/maxx/pull/12),
  [`d0aa656`](https://github.com/watermarkhu/maxx/commit/d0aa656d4055980454f35c00189431c638e22f2a))

- Use env to release ([#13](https://github.com/watermarkhu/maxx/pull/13),
  [`38ce50f`](https://github.com/watermarkhu/maxx/commit/38ce50f4accb87dcd2d08820d1aff03d7eb52601))


## v0.2.1 (2025-07-01)

### Bug Fixes

- Apply fixes for mkdocstrings-matlab ([#9](https://github.com/watermarkhu/maxx/pull/9),
  [`0bfe68a`](https://github.com/watermarkhu/maxx/commit/0bfe68abbc4743caa09cc02ed57f006a711a261f))

- Various fixes for mkdocstrings-matlab ([#9](https://github.com/watermarkhu/maxx/pull/9),
  [`0bfe68a`](https://github.com/watermarkhu/maxx/commit/0bfe68abbc4743caa09cc02ed57f006a711a261f))


## v0.2.0 (2025-06-02)

### Features

- Force release with semver action ([#7](https://github.com/watermarkhu/maxx/pull/7),
  [`1728e0f`](https://github.com/watermarkhu/maxx/commit/1728e0fcbd878353f11441af12d23da7d5444e88))

- Force release with semver action ([#6](https://github.com/watermarkhu/maxx/pull/6),
  [`5b23575`](https://github.com/watermarkhu/maxx/commit/5b23575d7821faf2c1064892ae12f533bbb657e3))

- Force release with semver action ([#5](https://github.com/watermarkhu/maxx/pull/5),
  [`cf7cefd`](https://github.com/watermarkhu/maxx/commit/cf7cefdbb187755143702aefcfc2fd962b73fae5))


## v0.1.0 (2025-05-24)
